@@ -1,6 +1,6 @@
-#!D:\bld\gdal-split_1595893984028\_h_env\python.exe
+#!D:\bld\gdal-split_1602162169053\_h_env\python.exe
 ###############################################################################
-# $Id: gdal_merge.py 428d6fbc987332afb0ba6c7b6913390f7386e864 2020-01-17 22:19:28 +0100 Even Rouault $
+# $Id: gdal_merge.py 73059f15f16f847f89f9e6296beff4f561ef4608 2020-07-17 19:23:30 +0200 Even Rouault $
 #
 # Project:  InSAR Peppers
 # Purpose:  Module to extract data from many rasters into one output.
@@ -325,8 +325,8 @@ class file_info(object):
             return 1
 
         # Compute source window in pixel coordinates.
-        sw_xoff = int((tgw_ulx - self.geotransform[0]) / self.geotransform[1])
-        sw_yoff = int((tgw_uly - self.geotransform[3]) / self.geotransform[5])
+        sw_xoff = int((tgw_ulx - self.geotransform[0]) / self.geotransform[1] + 0.1)
+        sw_yoff = int((tgw_uly - self.geotransform[3]) / self.geotransform[5] + 0.1)
         sw_xsize = int((tgw_lrx - self.geotransform[0]) /
                        self.geotransform[1] + 0.5) - sw_xoff
         sw_ysize = int((tgw_lry - self.geotransform[3]) /
